@@ -279,7 +279,7 @@ class DataNode(DatasetManager):
             return meta, io.BytesIO(response.data)
         
     
-    def read_ddf(self, file_id=None, index=0, extra_param=None):
+    def read_ddf(self, file_id=None, index=0, extra_param={}):
         """_summary_
 
         Args:
@@ -554,6 +554,8 @@ class DatabaseManagement(Base):
     
     def _create_pandas_meta(self, meta, pk_column):
         meta_dask = pd.DataFrame(columns=list(meta.keys()))
+        if meta[pk_column] == 'Int64':
+            meta[pk_column] = 'int64'
         meta_dask = meta_dask.astype(meta)
         meta_dask = meta_dask.set_index(pk_column)
         return meta_dask
@@ -672,6 +674,7 @@ from sqlalchemy import sql
                                 "replace": _replace
                           }
         )
+        check_http_status_code(res)
         return res.json() if res.status_code < 500 else res.content
     
     def _get_possible_str_division(self):
