@@ -1,4 +1,5 @@
-class Task(_Base):
+from . import base
+class Task(base.Base):
     def __init__(self):
         pass
     
